==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/RouteSpecHttp2RouteActionWeightedTargetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteActionWeightedTargetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property port The targeted port of the weighted object.
 * @property virtualNode Virtual node to associate with the weighted target. Must be between 1 and 255 characters in length.
 * @property weight Relative weight of the weighted target. An integer between 0 and 100.
 */
public data class RouteSpecHttp2RouteActionWeightedTargetArgs(
    public val port: Output<Int>? = null,
    public val virtualNode: Output<String>,
    public val weight: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteActionWeightedTargetArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteActionWeightedTargetArgs =
        com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteActionWeightedTargetArgs.builder()
            .port(port?.applyValue({ args0 -> args0 }))
            .virtualNode(virtualNode.applyValue({ args0 -> args0 }))
            .weight(weight.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteSpecHttp2RouteActionWeightedTargetArgs].
 */
@PulumiTagMarker
public class RouteSpecHttp2RouteActionWeightedTargetArgsBuilder internal constructor() {
    private var port: Output<Int>? = null

    private var virtualNode: Output<String>? = null

    private var weight: Output<Int>? = null

    /**
     * @param value The targeted port of the weighted object.
     */
    @JvmName("goxgdlevjxlsjmhd")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Virtual node to associate with the weighted target. Must be between 1 and 255 characters in length.
     */
    @JvmName("xvkbtjjyrbtvtktv")
    public suspend fun virtualNode(`value`: Output<String>) {
        this.virtualNode = value
    }

    /**
     * @param value Relative weight of the weighted target. An integer between 0 and 100.
     */
    @JvmName("nvwldoapqbsjchag")
    public suspend fun weight(`value`: Output<Int>) {
        this.weight = value
    }

    /**
     * @param value The targeted port of the weighted object.
     */
    @JvmName("ddjkrrkxbjfigqpi")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Virtual node to associate with the weighted target. Must be between 1 and 255 characters in length.
     */
    @JvmName("vgenmlyxavmhdspu")
    public suspend fun virtualNode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNode = mapped
    }

    /**
     * @param value Relative weight of the weighted target. An integer between 0 and 100.
     */
    @JvmName("irpqadesvfdnbctu")
    public suspend fun weight(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.weight = mapped
    }

    internal fun build(): RouteSpecHttp2RouteActionWeightedTargetArgs =
        RouteSpecHttp2RouteActionWeightedTargetArgs(
            port = port,
            virtualNode = virtualNode ?: throw PulumiNullFieldException("virtualNode"),
            weight = weight ?: throw PulumiNullFieldException("weight"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/RouteSpecHttp2RouteActionWeightedTargetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteActionWeightedTargetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property port The targeted port of the weighted object.
 * @property virtualNode Virtual node to associate with the weighted target. Must be between 1 and 255 characters in length.
 * @property weight Relative weight of the weighted target. An integer between 0 and 100.
 */
public data class RouteSpecHttp2RouteActionWeightedTargetArgs(
    public val port: Output<Int>? = null,
    public val virtualNode: Output<String>,
    public val weight: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteActionWeightedTargetArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteActionWeightedTargetArgs =
        com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteActionWeightedTargetArgs.builder()
            .port(port?.applyValue({ args0 -> args0 }))
            .virtualNode(virtualNode.applyValue({ args0 -> args0 }))
            .weight(weight.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteSpecHttp2RouteActionWeightedTargetArgs].
 */
@PulumiTagMarker
public class RouteSpecHttp2RouteActionWeightedTargetArgsBuilder internal constructor() {
    private var port: Output<Int>? = null

    private var virtualNode: Output<String>? = null

    private var weight: Output<Int>? = null

    /**
     * @param value The targeted port of the weighted object.
     */
    @JvmName("fhwtymxsgxonfyol")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Virtual node to associate with the weighted target. Must be between 1 and 255 characters in length.
     */
    @JvmName("pbftohfpogwnfsde")
    public suspend fun virtualNode(`value`: Output<String>) {
        this.virtualNode = value
    }

    /**
     * @param value Relative weight of the weighted target. An integer between 0 and 100.
     */
    @JvmName("hbjxnjydkrcvonwo")
    public suspend fun weight(`value`: Output<Int>) {
        this.weight = value
    }

    /**
     * @param value The targeted port of the weighted object.
     */
    @JvmName("cuvjaannbxjnhfsx")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Virtual node to associate with the weighted target. Must be between 1 and 255 characters in length.
     */
    @JvmName("kyyemaeetjpajhyo")
    public suspend fun virtualNode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNode = mapped
    }

    /**
     * @param value Relative weight of the weighted target. An integer between 0 and 100.
     */
    @JvmName("lxtfxgycujuqcvir")
    public suspend fun weight(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.weight = mapped
    }

    internal fun build(): RouteSpecHttp2RouteActionWeightedTargetArgs =
        RouteSpecHttp2RouteActionWeightedTargetArgs(
            port = port,
            virtualNode = virtualNode ?: throw PulumiNullFieldException("virtualNode"),
            weight = weight ?: throw PulumiNullFieldException("weight"),
        )
}
